****************** Sezione mobilit attiva

******* traduzione della Sintassi SAS di Laura Battisti (Trento)

********** NB. attenzione alla diversa gestione del missing di SAS e Stata

**** definisco chi utilizza la bicicletta per spostamenti quotidiani

gen uso_bici=.
replace uso_bici=1 if s20_uso_bici==1
replace uso_bici=0 if s20_uso_bici==2 | s20_uso_bici==-99

*** metto missing i non so (-99) in minuti e giorni, gli zero minuti o giorni e gli oltre 240 minuti per singola occasione,
*** e i missing in giorni o minuti (Laura Battisti)
replace uso_bici=. if s20_uso_bici==1 & (s20_gg_uso_bici<=0 | s20_min_uso_bici<=0 | s20_min_uso_bici>240 | s20_gg_uso_bici==. | s20_min_uso_bici==.)

label define uso_bici 1 "1 si" 0 "0 no"
label value uso_bici uso_bici

**** definisco chi va a piedi per spostamenti quotidiani
gen tragitti_piedi=.
replace tragitti_piedi=1 if s20_tragitti_a_piedi==1
replace tragitti_piedi=0 if s20_tragitti_a_piedi==2 | s20_tragitti_a_piedi==-99

*** metto missing i non so (-99) in minuti e giorni, gli zero minuti o giorni e gli oltre 240 minuti per singola occasione
*** e i missing in giorni o minuti (Laura Battisti)
replace tragitti_piedi=. if s20_tragitti_a_piedi==1 & (s20_gg_tragitti_a_piedi<=0 | s20_min_tragitti_a_piedi<=0 | s20_min_tragitti_a_piedi>240 | s20_gg_tragitti_a_piedi==. | s20_min_tragitti_a_piedi==.)

label define tragitti_piedi 1 "1 si" 0 "0 no"
label value tragitti_piedi tragitti_piedi

***** definisco una variabile che mi indica chi usa la bici o fa tragitti a piedi, chi fa entrambe le cose e chi non fa nulla
gen mobattiva=0
replace mobattiva=1 if uso_bici==1 | tragitti_piedi==1
replace mobattiva=2 if uso_bici==1 & tragitti_piedi==1 
replace mobattiva=. if uso_bici==. & tragitti_piedi==.

label define mobattiva 1 "1 bici o tragitti piedi" 2 "2 bici e tragitti piedi" 0 "0 nulla"
label value mobattiva mobattiva

***** definisco una variabile che mi indica chi usa la bici o fa tragitti a piedi e chi non fa nulla (dicotomica)
recode mobattiva (1 2 = 1 "1 si") (0 = 0 "0 no"), gen(mobattiva_log)

***** definisco una variabile che mi indica chi usa la bici o fa tragitti a piedi, chi fa entrambe le cose e chi non fa nulla
***** combinazione letterale
***** (userei questa variabile solo come variabile ausiliaria per definire i minuti e i giorni di mobilit attiva complessiva)

gen mobattiva_2="00"
replace mobattiva_2="10" if uso_bici==1 & (tragitti_piedi==0 | tragitti_piedi==.)
replace mobattiva_2="01" if (uso_bici==0 | uso_bici==.) & tragitti_piedi==1 
replace mobattiva_2="11" if uso_bici==1 & tragitti_piedi==1 
replace mobattiva_2="" if uso_bici==. & tragitti_piedi==.

*************

***** ricodifica dei minuti di uso della bicicletta
***** metto missing i non so (-99), i valori superiori a 240 e metto zero quelli compresi tra 1 e 9 (raccomandazioni OMS 2010: almeno 10 minuti)

gen s_min_uso_bici=s20_min_uso_bici
replace s_min_uso_bici=0 if s20_uso_bici==1 & s20_min_uso_bici>=1 & s20_min_uso_bici<10
replace s_min_uso_bici=. if s20_uso_bici==1 & (s20_gg_uso_bici<=0 | s20_min_uso_bici<=0 | s20_min_uso_bici>240  | s20_gg_uso_bici==. | s20_min_uso_bici==.)

***** ricodifica dei minuti dei tragitti a piedi
***** metto missing i non so (-99), i valori superiori a 240 e metto zero quelli compresi tra 1 e 9 (raccomandazioni OMS 2010: almeno 10 minuti)
gen s_min_tragitti_a_piedi=s20_min_tragitti_a_piedi
replace s_min_tragitti_a_piedi=0 if s20_tragitti_a_piedi==1 & s20_min_tragitti_a_piedi>=1 & s20_min_tragitti_a_piedi<10
replace s_min_tragitti_a_piedi=. if s20_tragitti_a_piedi==1 & (s20_gg_tragitti_a_piedi<=0 | s20_min_tragitti_a_piedi<=0 | s20_min_tragitti_a_piedi>240 | s20_gg_tragitti_a_piedi==. | s20_min_tragitti_a_piedi==.)

***************

**** ricodifica dei giorni di uso della bicicletta
*** metto missing i non so (-99) in minuti e giorni, gli zero minuti o giorni e gli oltre 240 minuti per singola occasione

gen s_gg_uso_bici=s20_gg_uso_bici 
replace s_gg_uso_bici=. if s20_gg_uso_bici<=0 | s20_min_uso_bici<=0 | s20_min_uso_bici>240   | s20_gg_uso_bici==. | s20_min_uso_bici==.

**** ricodifica dei giorni di tragitti a piedi 

gen s_gg_tragitti_a_piedi=s20_gg_tragitti_a_piedi
replace s_gg_tragitti_a_piedi=. if s20_gg_tragitti_a_piedi<=0 | s20_min_tragitti_a_piedi<=0 | s20_min_tragitti_a_piedi>240 | s20_gg_tragitti_a_piedi==. | s20_min_tragitti_a_piedi==.

****************

*** genero una variabile che mi dice i minuti settimanali in bici
gen  min_sett_bici=s_gg_uso_bici*s_min_uso_bici

*** minuti settimanali a piedi*/
gen min_sett_piedi=s_gg_tragitti_a_piedi*s_min_tragitti_a_piedi

**** genero una variabile che mi dice i minuti alla settimana complessivi
**** (la somma viene calcolata anche se una delle due variabili risulta missing)

egen min_sett=rowtotal(min_sett_bici min_sett_piedi),m 

***** calcolo i minuti alla settimana di mobilit attiva complessiva (bici e tragitti a piedi)
***** nb. numero di decimali diversi ma non crea problemi nella creazione delle categorie
gen double min_gg_medi_bici=min_sett_bici/7
gen double min_gg_medi_piedi=min_sett_piedi/7
gen double min_gg_medi_tot=min_sett/7

***** definisco la classificazione a 3 cat delle persone rispetto alla mobilitࡡttiva
***** nb attenzione!!!!!!!!!!!!!!!!!!

gen mob_fisica=3 if mobattiva==0 | (min_sett>=0 & min_sett<10)  | min_sett==.
replace mob_fisica=1 if min_sett>=150 & min_sett!=.
replace mob_fisica=2 if min_sett>=10 & min_sett<150
replace mob_fisica=. if mobattiva==.

label define mob_fisica 1 "1 attivo" 2 "2 parzialmente attivo" 3 "3 non attivo" 
label value mob_fisica mob_fisica

***** definisco la classificazione a 4 cat delle persone rispetto alla mobilitࡡttiva

gen mob_fisica_4cat=4 if mobattiva==0 | (min_sett>=0 & min_sett<10)  | min_sett==.
replace mob_fisica_4cat=1 if min_sett>=300 & min_sett!=.
replace mob_fisica_4cat=2 if min_sett>=150 & min_sett<300
replace mob_fisica_4cat=3 if min_sett>=10 & min_sett<150
replace mob_fisica_4cat=. if mobattiva==.

label define mob_fisica_4cat 1 "1 molto attivo" 2 "2 attivo" 3 "3 parzialmente attivo" 4 "4 non attivo" 
label value mob_fisica_4cat mob_fisica_4cat

***** definisco la classificazione a 2 cat delle persone rispetto alla mobilitࡡttiva per logistica

recode mob_fisica (1 = 1 "1 si") (2 3 = 0 "0 no"), gen(mob_fisica_log)


**************************
*********definisco la classificazione delle persone rispetto alla mobilità attiva senza limite dei 10 minuti


***** definisco la classificazione a 3 cat delle persone rispetto alla mobilitࡡttiva
***** nb attenzione!!!!!!!!!!!!!!!!!!

gen mob_fisica_2020=3 if mobattiva==0 | min_sett==0  | min_sett==.
replace mob_fisica_2020=1 if min_sett>=150 & min_sett!=.
replace mob_fisica_2020=2 if min_sett>0 & min_sett<150
replace mob_fisica_2020=. if mobattiva==.
label define mob_fisica_2020 1 "1 attivo" 2 "2 parzialmente attivo" 3 "3 non attivo" 
label value mob_fisica_2020 mob_fisica_2020

***** definisco la classificazione a 4 cat delle persone rispetto alla mobilitࡡttiva

gen mob_fisica_2020_4cat=4 if mobattiva==0 | min_sett==0  | min_sett==.
replace mob_fisica_2020_4cat=1 if min_sett>=300 & min_sett!=.
replace mob_fisica_2020_4cat=2 if min_sett>=150 & min_sett<300
replace mob_fisica_2020_4cat=3 if min_sett>0 & min_sett<150
replace mob_fisica_2020_4cat=. if mobattiva==.
label define mob_fisica_2020_4cat 1 "1 molto attivo" 2 "2 attivo" 3 "3 parzialmente attivo" 4 "4 non attivo" 
label value mob_fisica_2020_4cat mob_fisica_2020_4cat

***** definisco la classificazione a 2 cat delle persone rispetto alla mobilitࡡttiva per logistica

recode mob_fisica_2020 (1 = 1 "1 si") (2 3 = 0 "0 no"), gen(mob_fisica_2020_log)

************************

******************************************************************************************************

****** definisco una variabile che mi indica quanti gg di mobilit (tra chi fa mobilit attiva)

****** NB. non tiene conto del limite dei 10 minuti

**** persone che utilizzano solo la bicicletta
gen gg_mobilita=s20_gg_uso_bici if mobattiva_2=="10"

**** persone che fanno solo tragitti a piedi
replace gg_mobilita=s20_gg_tragitti_a_piedi if mobattiva_2=="01" 

***** persone che utilizzano la bicicletta e fanno tragitti a piedi:

***** - fanno per pi giorni spostamenti abituali in bicicletta
replace gg_mobilita=s20_gg_uso_bici if mobattiva_2=="11" & s20_gg_uso_bici>s20_gg_tragitti_a_piedi & s20_min_uso_bici!=.

***** - fanno per pi giorni spostamenti abituali a piedi
replace gg_mobilita=s20_gg_tragitti_a_piedi if mobattiva_2=="11" & s20_gg_tragitti_a_piedi>s20_gg_uso_bici & s20_gg_tragitti_a_piedi!=.

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma ha missing i giorni in cui fa tragitti a piedi (NB. per SAS il missing  un n. infinitesimamente basso)
replace gg_mobilita=s20_gg_uso_bici if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==.

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma ha missing i giorni in cui usa la bici (NB. per SAS il missing  un n. infinitesimamente basso)
replace gg_mobilita=s20_gg_tragitti_a_piedi if mobattiva_2=="11" & s20_gg_uso_bici==.

********* stessi giorni -> guardo minuti

replace gg_mobilita=s20_gg_uso_bici if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==s20_gg_uso_bici

***************

****** definisco una variabile che mi indica quanti minuti di mobilit (tra chi fa mobilit attiva)

**** persone che utilizzano solo la bicicletta o hanno missing l'informazione sui tragitti a piedi
gen min_mobilita=s20_min_uso_bici if mobattiva_2=="10"

**** persone che fanno solo tragitti a piedio hanno missing l'informazione sell'uso della bici
replace min_mobilita=s20_min_tragitti_a_piedi if mobattiva_2=="01"

***** persone che utilizzano la bicicletta e fanno tragitti a piedi:
***** - fanno per pi giorni spostamenti abituali in bicicletta
replace min_mobilita=s20_min_uso_bici if mobattiva_2=="11" & s20_gg_uso_bici>s20_gg_tragitti_a_piedi & s20_gg_uso_bici!=.

***** - fanno per pi giorni spostamenti abituali a piedi
replace min_mobilita=s20_min_tragitti_a_piedi if mobattiva_2=="11" & s20_gg_tragitti_a_piedi>s20_gg_uso_bici & s20_gg_tragitti_a_piedi!=.

********* stessi giorni -> guardo minuti

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma sono missing i minuti in cui fa tragitti a piedi
replace min_mobilita=s20_min_uso_bici if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==.

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma sono missing i minuti in cui 
replace min_mobilita=s20_min_tragitti_a_piedi if mobattiva_2=="11" & s20_gg_uso_bici==.

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma fanno pi minuti di bici
replace min_mobilita=s20_min_uso_bici if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==s20_gg_uso_bici & s20_min_uso_bici>s20_min_tragitti_a_piedi & s20_min_uso_bici!=.

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma fanno pi minuti a piedi
replace min_mobilita=s20_min_tragitti_a_piedi if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==s20_gg_uso_bici & s20_min_uso_bici<s20_min_tragitti_a_piedi & s20_min_tragitti_a_piedi!=.

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma fanno stessi minuti di bici e piedi
replace min_mobilita=s20_min_tragitti_a_piedi if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==s20_gg_uso_bici & s20_min_uso_bici==s20_min_tragitti_a_piedi

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma ha missing i minuti di bici e non di tragitti piedi (NB. per SAS il missing  un n. infinitesimamente basso)
replace min_mobilita=s20_min_tragitti_a_piedi if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==s20_gg_uso_bici & s20_min_uso_bici==. & s20_min_tragitti_a_piedi!=.

***** - fanno stessi giorni spostamenti abituali in bici e a piedi ma ha missing i minuti di tragitti a piedi e non di bici (NB. per SAS il missing  un n. infinitesimamente basso)
replace min_mobilita=s20_min_uso_bici if mobattiva_2=="11" & s20_gg_tragitti_a_piedi==s20_gg_uso_bici & s20_min_uso_bici!=. & s20_min_tragitti_a_piedi==.

**************

****** definisco una variabile che mi indica quanti giorni di mobilt su tutta la popolazione

gen gg_mobilita_2=gg_mobilita
replace gg_mobilita_2=0 if gg_mobilita==.
replace gg_mobilita_2=. if mobattiva==.





